# OctoprintJob


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**file** | [**OctoprintFile**](OctoprintFile.md) |  | [optional] 
**estimated_print_time** | **float** |  | [optional] 
**average_print_time** | **float** |  | [optional] 
**last_print_time** | **float** |  | [optional] 
**filament** | **dict(str, object)** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


